Archive Rest API — Rucio 1.2 documentation

# Archive Rest API

Overview

Resource | Operation | Description
--- | --- | ---
Archive | GET /archives/(scope)/(name) | list archive content keys.

Details

`GET` `/archives/`(scope)`/`(name)

  List archive content keys.

  Parameters: | scope – data identifier scope. name – data identifier name.
  Response Headers:
  | Content-Type – application/x-json-stream
  Status Codes: | 200 OK – OK. 500 Internal Server Error – Internal Error.